@@ -12,7 +12,7 @@ log = logging.getLogger(__name__)
 
 RESULT_VERSION = 4
 WIRE_VERSION = 1
-SPEC_VERSION = "1.5.0"
+SPEC_VERSION = "1.9.0"
 
 # This is a dictionary of torrc options we always want to set when launching
 # Tor and that do not depend on any runtime configuration
@@ -74,6 +74,18 @@ SUPERVISED_RUN_DPATH = "/run/sbws/tor"
 
 SOCKET_TIMEOUT = 60  # seconds
 
+# Possible `dirauth_nickname`s for BandithFiles in 2023
+DIRAUTH_NICKNAMES = [
+    "longclaw",
+    "gabelmoo",
+    "maatuska",
+    "bastet",
+    "moria1",
+    "dannenberg",
+    "dizum",
+    "tor26",
+    "test",
+]
 SBWS_SCALE_CONSTANT = 7500
 TORFLOW_SCALING = 1
 SBWS_SCALING = 2
