@@ -9,7 +9,6 @@ from queue import Empty, Queue
 from threading import RLock, Thread
 
 from sbws.globals import RESULT_VERSION, fail_hard
-from sbws.lib.relaylist import Relay
 from sbws.util.filelock import DirectoryLock
 from sbws.util.json import CustomDecoder, CustomEncoder
 
@@ -36,7 +35,6 @@ def load_result_file(fname, success_only=False):
     structures (or subclasses of Result). Optionally only keeps ResultSuccess.
     Returns all kept Results as a result dictionary. This function does not
     care about the age of the results"""
-    assert os.path.isfile(fname)
     d = {}
     num_total = 0
     num_ignored = 0
@@ -74,8 +72,6 @@ def load_result_file(fname, success_only=False):
 def trim_results(fresh_days, result_dict):
     """Given a result dictionary, remove all Results that are no longer valid
     and return the new dictionary"""
-    assert isinstance(fresh_days, int)
-    assert isinstance(result_dict, dict)
     data_period = fresh_days * 24 * 60 * 60
     oldest_allowed = time.time() - data_period
     out_results = {}
@@ -105,7 +101,6 @@ def trim_results_ip_changed(
         IPv6 changes
     :returns: a new results dictionary
     """
-    assert isinstance(result_dict, dict)
     new_results_dict = {}
     if on_changed_ipv4 is True:
         for fp in result_dict.keys():
@@ -146,8 +141,6 @@ def load_recent_results_in_datadir(
     """Given a data directory, read all results files in it that could have
     results in them that are still valid. Trim them, and return the valid
     Results as a list"""
-    assert isinstance(fresh_days, int)
-    assert os.path.isdir(datadir)
     # Inform the results are being loaded, since it takes some seconds.
     log.info("Reading and processing previous measurements.")
     results = {}
@@ -192,15 +185,23 @@ def load_recent_results_in_datadir(
 
 def write_result_to_datadir(result, datadir):
     """Can be called from any thread"""
-    assert isinstance(result, Result)
-    assert os.path.isdir(datadir)
     dt = datetime.utcfromtimestamp(result.time)
     ext = ".txt"
     result_fname = os.path.join(datadir, "{}{}".format(dt.date(), ext))
-    with DirectoryLock(datadir):
-        log.debug("Writing a result to %s", result_fname)
-        with open(result_fname, "at") as fd:
-            fd.write("{}\n".format(str(result)))
+    try:
+        with DirectoryLock(datadir):
+            log.debug("Writing a result to %s", result_fname)
+            with open(result_fname, "at") as fd:
+                fd.write("{}\n".format(str(result)))
+    # Catch any exception writing.
+    except Exception as e:
+        log.error(
+            "Can not write to datadir %s: %s. "
+            "Please check that there is enough space in disk "
+            "and the directory has the correct permissions.",
+            datadir,
+            e,
+        )
 
 
 class _StrEnum(str, Enum):
@@ -254,6 +255,8 @@ class Result:
             relay_in_recent_consensus=None,
             relay_recent_measurement_attempt=None,
             relay_recent_priority_list=None,
+            xoff_recv=None,
+            xoff_sent=None,
         ):
             """
             Initializes a ``Result.Relay``.
@@ -280,6 +283,8 @@ class Result:
                 relay_recent_measurement_attempt
             )
             self.relay_recent_priority_list = relay_recent_priority_list
+            self.xoff_recv = xoff_recv
+            self.xoff_sent = xoff_sent
 
     def __init__(self, relay, circ, dest_url, scanner_nick, t=None):
         """
@@ -299,6 +304,8 @@ class Result:
             relay.relay_in_recent_consensus,
             relay.relay_recent_measurement_attempt,
             relay.relay_recent_priority_list,
+            relay.xoff_recv,
+            relay.xoff_sent,
         )
         self._circ = circ
         self._dest_url = dest_url
@@ -368,6 +375,14 @@ class Result:
         """
         return self._relay.relay_recent_priority_list
 
+    @property
+    def xoff_recv(self):
+        return self._relay.xoff_recv
+
+    @property
+    def xoff_sent(self):
+        return self._relay.xoff_sent
+
     @property
     def circ(self):
         return self._circ
@@ -403,6 +418,8 @@ class Result:
             "relay_in_recent_consensus": self.relay_in_recent_consensus,
             "relay_recent_measurement_attempt": self.relay_recent_measurement_attempt,  # noqa
             "relay_recent_priority_list": self.relay_recent_priority_list,
+            "xoff_recv": self.xoff_recv,
+            "xoff_sent": self.xoff_sent,
         }
 
     @staticmethod
@@ -422,10 +439,8 @@ class Result:
 
            ``version`` is not being used and should be removed.
         """
-        assert "version" in d
         if d["version"] != RESULT_VERSION:
             return None
-        assert "type" in d
         if d["type"] == _ResultType.Success.value:
             return ResultSuccess.from_dict(d)
         elif d["type"] == _ResultType.Error.value:
@@ -481,7 +496,6 @@ class ResultError(Result):
 
     @staticmethod
     def from_dict(d):
-        assert isinstance(d, dict)
         return ResultError(
             Result.Relay(
                 d["fingerprint"],
@@ -497,6 +511,8 @@ class ResultError(Result):
                 relay_recent_priority_list=d.get(  # noqa
                     "relay_recent_priority_list", None
                 ),  # noqa
+                xoff_recv=d.get("xoff_recv", None),
+                xoff_sent=d.get("xoff_sent", None),
             ),
             d["circ"],
             d["dest_url"],
@@ -536,7 +552,6 @@ class ResultErrorCircuit(ResultError):
 
     @staticmethod
     def from_dict(d):
-        assert isinstance(d, dict)
         return ResultErrorCircuit(
             Result.Relay(
                 d["fingerprint"],
@@ -552,6 +567,8 @@ class ResultErrorCircuit(ResultError):
                 relay_recent_priority_list=d.get(  # noqa
                     "relay_recent_priority_list", None
                 ),  # noqa
+                xoff_recv=d.get("xoff_recv", None),
+                xoff_sent=d.get("xoff_sent", None),
             ),
             d["circ"],
             d["dest_url"],
@@ -575,7 +592,6 @@ class ResultErrorStream(ResultError):
 
     @staticmethod
     def from_dict(d):
-        assert isinstance(d, dict)
         return ResultErrorStream(
             Result.Relay(
                 d["fingerprint"],
@@ -591,6 +607,8 @@ class ResultErrorStream(ResultError):
                 relay_recent_priority_list=d.get(  # noqa
                     "relay_recent_priority_list", None
                 ),  # noqa
+                xoff_recv=d.get("xoff_recv", None),
+                xoff_sent=d.get("xoff_sent", None),
             ),
             d["circ"],
             d["dest_url"],
@@ -634,7 +652,6 @@ class ResultErrorSecondRelay(ResultError):
 
     @staticmethod
     def from_dict(d):
-        assert isinstance(d, dict)
         return ResultErrorSecondRelay(
             Result.Relay(
                 d["fingerprint"],
@@ -650,6 +667,8 @@ class ResultErrorSecondRelay(ResultError):
                 relay_recent_priority_list=d.get(  # noqa
                     "relay_recent_priority_list", None
                 ),  # noqa
+                xoff_recv=d.get("xoff_recv", None),
+                xoff_sent=d.get("xoff_sent", None),
             ),
             d["circ"],
             d["dest_url"],
@@ -686,7 +705,6 @@ class ResultErrorDestination(ResultError):
 
     @staticmethod
     def from_dict(d):
-        assert isinstance(d, dict)
         return ResultErrorSecondRelay(
             Result.Relay(
                 d["fingerprint"],
@@ -705,6 +723,8 @@ class ResultErrorDestination(ResultError):
                 relay_recent_priority_list=d.get(  # noqa
                     "relay_recent_priority_list", None
                 ),  # noqa
+                xoff_recv=d.get("xoff_recv", None),
+                xoff_sent=d.get("xoff_sent", None),
             ),
             msg=d["msg"],
             t=d["time"],
@@ -738,7 +758,6 @@ class ResultErrorAuth(ResultError):
 
     @staticmethod
     def from_dict(d):
-        assert isinstance(d, dict)
         return ResultErrorAuth(
             Result.Relay(
                 d["fingerprint"],
@@ -754,6 +773,8 @@ class ResultErrorAuth(ResultError):
                 relay_recent_priority_list=d.get(  # noqa
                     "relay_recent_priority_list", None
                 ),  # noqa
+                xoff_recv=d.get("xoff_recv", None),
+                xoff_sent=d.get("xoff_sent", None),
             ),
             d["circ"],
             d["dest_url"],
@@ -787,7 +808,6 @@ class ResultSuccess(Result):
 
     @staticmethod
     def from_dict(d):
-        assert isinstance(d, dict)
         return ResultSuccess(
             d["rtts"] or [],
             d["downloads"],
@@ -810,6 +830,8 @@ class ResultSuccess(Result):
                 relay_recent_priority_list=d.get(  # noqa
                     "relay_recent_priority_list", None
                 ),  # noqa
+                xoff_recv=d.get("xoff_recv", None),
+                xoff_sent=d.get("xoff_sent", None),
             ),
             d["circ"],
             d["dest_url"],
@@ -838,7 +860,6 @@ class ResultDump:
     queue. Writes them to daily result files in the data directory"""
 
     def __init__(self, args, conf):
-        assert os.path.isdir(conf.getpath("paths", "datadir"))
         self.conf = conf
         self.fresh_days = conf.getint("general", "data_period")
         self.datadir = conf.getpath("paths", "datadir")
@@ -853,7 +874,6 @@ class ResultDump:
 
     def store_result(self, result):
         """Call from ResultDump thread"""
-        assert isinstance(result, Result)
         with self.data_lock:
             fp = result.fingerprint
             if fp not in self.data:
@@ -868,7 +888,6 @@ class ResultDump:
     def handle_result(self, result):
         """Call from ResultDump thread. If we are shutting down, ignores
         ResultError* types"""
-        assert isinstance(result, Result)
         fp = result.fingerprint
         nick = result.nickname
         if isinstance(result, ResultError) and settings.end_event.is_set():
@@ -955,7 +974,6 @@ class ResultDump:
                 continue
             elif isinstance(data, list):
                 for r in data:
-                    assert isinstance(r, Result)
                     self.handle_result(r)
             elif isinstance(data, Result):
                 self.handle_result(data)
@@ -968,7 +986,6 @@ class ResultDump:
                 )
 
     def results_for_relay(self, relay):
-        assert isinstance(relay, Relay)
         fp = relay.fingerprint
         with self.data_lock:
             if fp not in self.data:
